==> jc-1.4.0.tar.gz: javax/swing/SwingUtilities__24OwnerFrame.h <==
// class javax.swing.SwingUtilities$OwnerFrame

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class c14a2362b2109d4 java_awt_Frame
// @dep_class 184d12f43c3697c9 java_awt_Window
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e711afbfad0d67e5 javax_swing_SwingUtilities__24OwnerFrame

// header file dependencies
// @dep_header java_awt_Frame

#include "java/awt/Frame.h"

#ifndef _JC_javax_swing_SwingUtilities__24OwnerFrame_H_
#define _JC_javax_swing_SwingUtilities__24OwnerFrame_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_SwingUtilities__241$object;

// Typedefs
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs	_jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs	_jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$refs	_jc_javax_swing_SwingUtilities__24OwnerFrame$refs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs	_jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object	_jc_javax_swing_SwingUtilities__24OwnerFrame$object;

typedef const struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods	_jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods;
typedef const struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtable	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtable;
typedef const struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtype	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtype;

// Constructors
extern void _jc_javax_swing_SwingUtilities__24OwnerFrame$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *);
extern void _jc_javax_swing_SwingUtilities__24OwnerFrame$method$_init$cff4427d068c2038(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *, struct _jc_javax_swing_SwingUtilities__241$object *);

// Virtual methods
extern jboolean _jc_javax_swing_SwingUtilities__24OwnerFrame$method$isShowing$87487545423a6e74(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *);
extern void _jc_javax_swing_SwingUtilities__24OwnerFrame$method$setVisible$d36d67c941379657(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SwingUtilities__24OwnerFrame$method_info$isShowing$87487545423a6e74;
extern _jc_method _jc_javax_swing_SwingUtilities__24OwnerFrame$method_info$setVisible$d36d67c941379657;

// Virtual methods structure
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods {
	jboolean	(*isShowing$87487545423a6e74)(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *);
	void	(*setVisible$d36d67c941379657)(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *, jboolean);
};

// Vtable
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Frame$vmethods	java_awt_Frame;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods	javax_swing_SwingUtilities__24OwnerFrame;
};

// Vtype
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtype {
	_jc_type			type;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$refs {
    _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs	javax_swing_SwingUtilities__24OwnerFrame;
    _jc_java_awt_Frame$sub_refs	java_awt_Frame;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Frame$sub_nonrefs	java_awt_Frame;
    _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs	javax_swing_SwingUtilities__24OwnerFrame;
};

// Object instance structure
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object {
	_jc_javax_swing_SwingUtilities__24OwnerFrame$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtype	*vtype;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SwingUtilities__24OwnerFrame$vtype _jc_javax_swing_SwingUtilities__24OwnerFrame$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SwingUtilities__24OwnerFrame, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SwingUtilities__24OwnerFrame$class_object;

#endif	/* _JC_javax_swing_SwingUtilities__24OwnerFrame_H_ */

==> jc-1.4.5.tar.gz: javax/swing/SwingUtilities__24OwnerFrame.h <==
// class javax.swing.SwingUtilities$OwnerFrame

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class f9fc65873f556df3 java_awt_Frame
// @dep_class fd4ae025aa56ceb9 java_awt_Window
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e711afbfad0d67e5 javax_swing_SwingUtilities__24OwnerFrame

// header file dependencies
// @dep_header java_awt_Frame

#include "java/awt/Frame.h"

#ifndef _JC_javax_swing_SwingUtilities__24OwnerFrame_H_
#define _JC_javax_swing_SwingUtilities__24OwnerFrame_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_SwingUtilities__241$object;

// Typedefs
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs	_jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs	_jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$refs	_jc_javax_swing_SwingUtilities__24OwnerFrame$refs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs	_jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs;
typedef struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object	_jc_javax_swing_SwingUtilities__24OwnerFrame$object;

typedef const struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods	_jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods;
typedef const struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtable	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtable;
typedef const struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtype	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtype;

// Constructors
extern void _jc_javax_swing_SwingUtilities__24OwnerFrame$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SwingUtilities__24OwnerFrame$method$_init$cff4427d068c2038(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *, struct _jc_javax_swing_SwingUtilities__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_SwingUtilities__24OwnerFrame$method$isShowing$87487545423a6e74(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SwingUtilities__24OwnerFrame$method$setVisible$d36d67c941379657(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SwingUtilities__24OwnerFrame$method_info$isShowing$87487545423a6e74;
extern _jc_method _jc_javax_swing_SwingUtilities__24OwnerFrame$method_info$setVisible$d36d67c941379657;

// Virtual methods structure
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods {
	jboolean	(*isShowing$87487545423a6e74)(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *) _JC_JCNI_ATTR;
	void	(*setVisible$d36d67c941379657)(_jc_env *, struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Frame$vmethods	java_awt_Frame;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$vmethods	javax_swing_SwingUtilities__24OwnerFrame;
};

// Vtype
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$vtype {
	_jc_type			type;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$refs {
    _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_refs	javax_swing_SwingUtilities__24OwnerFrame;
    _jc_java_awt_Frame$sub_refs	java_awt_Frame;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Frame$sub_nonrefs	java_awt_Frame;
    _jc_javax_swing_SwingUtilities__24OwnerFrame$sub_nonrefs	javax_swing_SwingUtilities__24OwnerFrame;
};

// Object instance structure
struct _jc_javax_swing_SwingUtilities__24OwnerFrame$object {
	_jc_javax_swing_SwingUtilities__24OwnerFrame$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$vtype	*vtype;
	_jc_javax_swing_SwingUtilities__24OwnerFrame$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SwingUtilities__24OwnerFrame$vtype _jc_javax_swing_SwingUtilities__24OwnerFrame$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SwingUtilities__24OwnerFrame, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SwingUtilities__24OwnerFrame$class_object;

#endif	/* _JC_javax_swing_SwingUtilities__24OwnerFrame_H_ */
